pub enum HookAction {
Heartbeat,
Started {
project_name: String,
},
Switched {
from: String,
to: String,
},
Stopped {
project_name: String,
},
SessionCreated,
SessionStarted {
project_name: String,
},
IdleResume {
project_name: String,
},
}Expand description
What happened as a result of the hook firing.
Variants
Heartbeat
Session heartbeat updated, no project change.
Started
Started tracking a new project.
Switched
Switched from one project to another.
Stopped
Stopped tracking (left project directory).
SessionCreated
New session created, no project detected.
SessionStarted
New session created and started tracking.
IdleResume
Idle gap detected; previous entry stopped at last heartbeat, new one started.